Learn R Programming

prefmod (version 0.8-37)

euro55.2.des: Design data frame for a paired comparison pattern model for rankings (Eurobarometer 55.2)

Description

Eurobarometer public opinion surveys have been carried out in all member states of the European Union since 1973. Eurobarometer 55.2 was a special survey collected in 2001 and designed to elicit information on European experience and perception of science and technology. One question, of identical form in all states, asked respondents about their sources of information about science, and requested them to rank them in order of importance. The items were: Television, Radio, Press, Scientific Magazines, Internet, School and University.

Usage

euro55.2.des

Arguments

Format

The data is a design data frame generated from the original data using patt.design. Each row represents a (derived) paired comparison response pattern crossclassified by the categorical subject covariates SEX and AGE4. The columns are:

y

counts

%
TV

design vector for Television

%
RAD

design vector for Radio

%
NEWSP

design vector for Newspapers and magazine

%
SCIMAG

design vector for Scientific magazines

%
WWW

design vector for The internet

%
EDINST

design vector for School/University

%
SEX

Gender: Factor with 2 levels: (1) male, (2) female

%
AGE4

Age: Factor with 4 levels: (1) 15--24, (2) 25--39, (3) 40--54, (4) 55+

%

Details

The original data contained 16 029 cases, after removal of cases with missing values and improper rankings this design data frame is based on 12216 observations.

References

Christensen, T. (2001). Eurobarometer 55.2: Europeans, science and technology. Technical report, European Opinion Research Group, Commission of the European Communities, Brussels.

Examples

Run this code
str(euro55.2.des)

Run the code above in your browser using DataLab