Learn R Programming

prefmod (version 0.8-32)

patt.worth: Function to calculate and print worth parameters from pattern model results

Description

Worth parameter are calculated from the results of a pattern model fit, i.e., from pattPC.fit, pattR.fit, pattL.fit, and pattLrep.fit or from a gnm-fit, respectively. For the latter, the function only works if the design matrix had been generated using patt.design.

Usage

patt.worth(fitobj, obj.names = NULL, outmat = "worth")

Arguments

fitobj
Object of class pattMod obtained from pattern model fit.
obj.names
names for the objects, for repeated measurement models just the names of objects for the first time point
outmat
a matrix of estimated worth parameters (outmat = "worth", the default) or pattern model parameters (outmat = "lambda").

Value

  • patt.worth returns a matrix of worth or model parameters. If subject covariates have been specified, each column represents a groups defined by the crossclassification of the subject covariates. The function plot gives a plot of the estimates.

encoding

UTF-8

Warning

If the pattern model has been fitted including numerical subject covariates, they are ignored. However, estimates for the remaining predictors are calculated for convenience. Please note, that these cannot be interpreted as standard estimates but are intercepts of the regression model where the objects (or reparameterized objects) are explained by one or more numerical subject covariates.

Details

If the pattern model includes categorical subject covariates, the function provides estimates for all groups formed by the full crossclassification. Numerical subject covariates are not implemented (yet)(see Warning below).

See Also

pattPC.fit, pattR.fit, pattL.fit, and pattLrep.fit, plot

Examples

Run this code
# fit only first three objects with SEX effect
m2 <- pattPC.fit(cemspc, nitems = 3, formel = ~SEX, elim = ~SEX, undec = TRUE)

# calculate and print worth parameters
m2worth <- patt.worth(m2)
m2worth

Run the code above in your browser using DataLab